summaryrefslogtreecommitdiffstats
path: root/chrome/browser/profile.h
diff options
context:
space:
mode:
authoragl@chromium.org <agl@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-12-11 21:04:42 +0000
committeragl@chromium.org <agl@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-12-11 21:04:42 +0000
commit326e67907033c1e8db115327d59482b1ae6db3ec (patch)
tree2940d88e6de6ce6ba528c4671b6574b4ff6bd1bd /chrome/browser/profile.h
parent5973945e4c3d2baf2b92d11be55c1692a09b12e3 (diff)
downloadchromium_src-326e67907033c1e8db115327d59482b1ae6db3ec.zip
chromium_src-326e67907033c1e8db115327d59482b1ae6db3ec.tar.gz
chromium_src-326e67907033c1e8db115327d59482b1ae6db3ec.tar.bz2
SPDY: augment Strict Transport Security with the beginnings of SPDY upgrade.
This adds an opportunistic flag to the information that we store in the Strict Transport Security State. Given this, STSS might be misnamed now, but renaming it in this patch would add huge amounts of noise. We process the 'X-Bodge-Transport-Security' header which has the same format as the STS header. When we see this on an HTTP connection, we'll probe for a clean HTTPS path to the host and then remember it. This header should be considered mutually exclusive with STS, although this isn't enforced in the code. The remembered flag is currently ignored by the rest of the code. This will be addressed in a future patch. The header should be called 'Opportunistic-Transport-Security' in the future, but we have some issues to work out before we take that name. http://codereview.chromium.org/456011 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@34380 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/profile.h')
-rw-r--r--chrome/browser/profile.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/chrome/browser/profile.h b/chrome/browser/profile.h
index 2a1c065..815dc22 100644
--- a/chrome/browser/profile.h
+++ b/chrome/browser/profile.h
@@ -22,7 +22,7 @@
#endif
namespace net {
-class StrictTransportSecurityState;
+class TransportSecurityState;
class SSLConfigService;
}
@@ -55,7 +55,7 @@ class SessionService;
class SpellCheckHost;
class SSLConfigServiceManager;
class SSLHostState;
-class StrictTransportSecurityPersister;
+class TransportSecurityPersister;
class SQLitePersistentCookieStore;
class TabRestoreService;
class TemplateURLFetcher;
@@ -174,11 +174,11 @@ class Profile {
// called.
virtual SSLHostState* GetSSLHostState() = 0;
// Retrieves a pointer to the StrictTransportSecurityState associated with
// this profile. The StrictTransportSecurityState is lazily created the
// first time that this method is called.
- virtual net::StrictTransportSecurityState*
- GetStrictTransportSecurityState() = 0;
+ virtual net::TransportSecurityState*
+ GetTransportSecurityState() = 0;
// Retrieves a pointer to the FaviconService associated with this
// profile. The FaviconService is lazily created the first time
@@ -408,7 +408,7 @@ class ProfileImpl : public Profile,
virtual VisitedLinkMaster* GetVisitedLinkMaster();
virtual UserScriptMaster* GetUserScriptMaster();
virtual SSLHostState* GetSSLHostState();
- virtual net::StrictTransportSecurityState* GetStrictTransportSecurityState();
+ virtual net::TransportSecurityState* GetTransportSecurityState();
virtual ExtensionsService* GetExtensionsService();
virtual ExtensionDevToolsManager* GetExtensionDevToolsManager();
virtual ExtensionProcessManager* GetExtensionProcessManager();
@@ -499,10 +499,10 @@ class ProfileImpl : public Profile,
scoped_ptr<ExtensionProcessManager> extension_process_manager_;
scoped_refptr<ExtensionMessageService> extension_message_service_;
scoped_ptr<SSLHostState> ssl_host_state_;
- scoped_refptr<net::StrictTransportSecurityState>
- strict_transport_security_state_;
- scoped_refptr<StrictTransportSecurityPersister>
- strict_transport_security_persister_;
+ scoped_refptr<net::TransportSecurityState>
+ transport_security_state_;
+ scoped_refptr<TransportSecurityPersister>
+ transport_security_persister_;
scoped_ptr<PrefService> prefs_;
scoped_refptr<ThumbnailStore> thumbnail_store_;
scoped_ptr<TemplateURLFetcher> template_url_fetcher_;
@@ -174,11 +174,11 @@ class Profile {
// called.
virtual SSLHostState* GetSSLHostState() = 0;
- // Retrieves a pointer to the StrictTransportSecurityState associated with
- // this profile. The StrictTransportSecurityState is lazily created the
+ // Retrieves a pointer to the TransportSecurityState associated with
+ // this profile. The TransportSecurityState is lazily created the
// first time that this method is called.